@@ -1,16 +1,19 @@
 use std::borrow::Cow;
 
 use itertools::Itertools;
+use tombi_ast::GetHeaderSchemarAccessors;
+use tombi_comment_directive::value::{TableCommonLintRules, TableFormatRules};
+use tombi_comment_directive_serde::get_comment_directive_content;
 use tombi_document_tree::IntoDocumentTreeAndErrors;
 use tombi_future::{BoxFuture, Boxable};
-use tombi_schema_store::{CurrentSchema, GetHeaderSchemarAccessors, SchemaAccessor};
+use tombi_schema_store::{Accessor, CurrentSchema};
 
 use crate::{edit::get_schema, rule::table_keys_order};
 
 impl crate::Edit for tombi_ast::ArrayOfTable {
     fn edit<'a: 'b, 'b>(
         &'a self,
-        _accessors: &'a [tombi_schema_store::SchemaAccessor],
+        _accessors: &'a [tombi_schema_store::Accessor],
         source_path: Option<&'a std::path::Path>,
         current_schema: Option<&'a tombi_schema_store::CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext<'a>,
@@ -19,12 +22,16 @@ impl crate::Edit for tombi_ast::ArrayOfTable {
 
         async move {
             let mut changes = vec![];
-            let Some(header_accessors) =
-                self.get_header_schema_accessor(schema_context.toml_version)
+            let Some(header_accessors) = self.get_header_accessor(schema_context.toml_version)
             else {
                 return changes;
             };
 
+            let comment_directive = get_comment_directive_content::<
+                TableFormatRules,
+                TableCommonLintRules,
+            >(self.comment_directives());
+
             let mut value = &tombi_document_tree::Value::Table(
                 self.clone()
                     .into_document_tree_and_errors(schema_context.toml_version)
@@ -45,13 +52,13 @@ impl crate::Edit for tombi_ast::ArrayOfTable {
 
             for header_accessor in &header_accessors {
                 match (value, header_accessor) {
-                    (tombi_document_tree::Value::Table(table), SchemaAccessor::Key(key)) => {
+                    (tombi_document_tree::Value::Table(table), Accessor::Key(key)) => {
                         let Some(v) = table.get(key) else {
                             return changes;
                         };
                         value = v;
                     }
-                    (tombi_document_tree::Value::Array(array), SchemaAccessor::Index) => {
+                    (tombi_document_tree::Value::Array(array), Accessor::Index(_)) => {
                         let Some(v) = array.get(0) else {
                             return changes;
                         };
@@ -80,6 +87,7 @@ impl crate::Edit for tombi_ast::ArrayOfTable {
                     self.key_values().collect_vec(),
                     current_schema.as_ref(),
                     schema_context,
+                    comment_directive,
                 )
                 .await,
             );
