@@ -3,14 +3,14 @@ use std::borrow::Cow;
 use itertools::Itertools;
 use tombi_document_tree::TryIntoDocumentTree;
 use tombi_future::{BoxFuture, Boxable};
-use tombi_schema_store::{CurrentSchema, SchemaAccessor};
+use tombi_schema_store::{Accessor, CurrentSchema};
 
 use super::get_schema;
 
 impl crate::Edit for tombi_ast::KeyValue {
     fn edit<'a: 'b, 'b>(
         &'a self,
-        _accessors: &'a [tombi_schema_store::SchemaAccessor],
+        _accessors: &'a [tombi_schema_store::Accessor],
         source_path: Option<&'a std::path::Path>,
         current_schema: Option<&'a tombi_schema_store::CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext<'a>,
@@ -24,11 +24,7 @@ impl crate::Edit for tombi_ast::KeyValue {
 
             let keys_accessors = keys
                 .keys()
-                .filter_map(|key| {
-                    key.try_to_raw_text(schema_context.toml_version)
-                        .ok()
-                        .map(SchemaAccessor::Key)
-                })
+                .map(|key| Accessor::Key(key.to_raw_text(schema_context.toml_version)))
                 .collect_vec();
 
             if let Some(current_schema) = current_schema {
