@@ -132,10 +132,11 @@ mod table_keys_order {
                   "tombi-formatter>=0.0.0",
                   # maturin leading comment1
                   # maturin leading comment2
-                  "maturin>=1.5,<2.0", # maturin tailing comment
+                  "maturin>=1.5,<2.0", # maturin trailing comment
                   # tombi-cli leading comment1
                   # tombi-cli leading comment2
-                  "tombi-cli>=0.0.0" # tombi-cli tailing comment
+                  "tombi-cli>=0.0.0" # tombi-cli trailing comment
+                  ,
                 ]
                 "#,
                 pyproject_schema_path(),
@@ -149,10 +150,10 @@ mod table_keys_order {
                 dependencies = [
                   # maturin leading comment1
                   # maturin leading comment2
-                  "maturin>=1.5,<2.0",  # maturin tailing comment
+                  "maturin>=1.5,<2.0",  # maturin trailing comment
                   # tombi-cli leading comment1
                   # tombi-cli leading comment2
-                  "tombi-cli>=0.0.0",  # tombi-cli tailing comment
+                  "tombi-cli>=0.0.0",  # tombi-cli trailing comment
                   "tombi-formatter>=0.0.0",
                   "tombi-linter>=0.0.0",
                 ]
@@ -172,7 +173,7 @@ mod table_keys_order {
 
                 [dependency-groups]
                 dev = [
-                  "pytest>=8.3.3", # pytest tailing comment
+                  "pytest>=8.3.3", # pytest trailing comment
                   "ruff>=0.7.4"
                 ]
                 "#,
@@ -187,13 +188,65 @@ mod table_keys_order {
 
                 [dependency-groups]
                 dev = [
-                  "pytest>=8.3.3",  # pytest tailing comment
+                  "pytest>=8.3.3",  # pytest trailing comment
                   "ruff>=0.7.4",
                 ]
                 "#,
             )
         }
 
+        test_format! {
+            #[tokio::test]
+            async fn test_dependency_groups_multiple_lines_include_group_with_comment(
+                r#"
+                [project]
+                name = "tombi"
+                version = "1.0.0"
+                requires-python = ">=3.10"
+                dependencies = []
+
+                [dependency-groups]
+                dev = [
+                  { include-group = "stub" },
+                  "pytest>=8.3.3",
+                  { include-group = "ci" },
+                  "ruff>=0.7.4",
+                ]
+                ci = [
+                  "ruff>=0.7.4",
+                  "pytest-ci>=0.0.0",
+                ]
+                stub = [
+                  "pytest-stub>=1.1.0",
+                ]
+                "#,
+                pyproject_schema_path(),
+            ) -> Ok(
+                r#"
+                [project]
+                name = "tombi"
+                version = "1.0.0"
+                requires-python = ">=3.10"
+                dependencies = []
+
+                [dependency-groups]
+                dev = [
+                  "pytest>=8.3.3",
+                  "ruff>=0.7.4",
+                  { include-group = "ci" },
+                  { include-group = "stub" },
+                ]
+                ci = [
+                  "pytest-ci>=0.0.0",
+                  "ruff>=0.7.4",
+                ]
+                stub = [
+                  "pytest-stub>=1.1.0",
+                ]
+                "#,
+            )
+        }
+
         test_format! {
             #[tokio::test]
             async fn test_tool_poetry_dependencies(
@@ -322,6 +375,62 @@ mod table_keys_order {
             )
         }
 
+        test_format! {
+            #[tokio::test]
+            async fn test_cargo_package_with_disabled_comment_directive(
+                r#"
+                # tombi: format.rules.table-keys-order.disabled = true
+                [package]
+                name = "toml-version"
+                authors = { workspace = true }
+                edition = { workspace = true }
+                license = { workspace = true }
+                repository = { workspace = true }
+                version = { workspace = true }
+                "#,
+                cargo_schema_path(),
+            ) -> Ok(
+                r#"
+                # tombi: format.rules.table-keys-order.disabled = true
+                [package]
+                name = "toml-version"
+                authors = { workspace = true }
+                edition = { workspace = true }
+                license = { workspace = true }
+                repository = { workspace = true }
+                version = { workspace = true }
+                "#
+            )
+        }
+
+        test_format! {
+            #[tokio::test]
+            async fn test_cargo_package_with_ascending_comment_directive(
+                r#"
+                # tombi: format.rules.table-keys-order = "ascending"
+                [package]
+                name = "toml-version"
+                authors = { workspace = true }
+                edition = { workspace = true }
+                license = { workspace = true }
+                repository = { workspace = true }
+                version = { workspace = true }
+                "#,
+                cargo_schema_path(),
+            ) -> Ok(
+                r#"
+                # tombi: format.rules.table-keys-order = "ascending"
+                [package]
+                authors = { workspace = true }
+                edition = { workspace = true }
+                license = { workspace = true }
+                name = "toml-version"
+                repository = { workspace = true }
+                version = { workspace = true }
+                "#
+            )
+        }
+
         test_format! {
             #[tokio::test]
             async fn test_dependencies_and_features(
@@ -342,8 +451,30 @@ mod table_keys_order {
                 serde = { version = "^1.0.0", features = ["derive"] }
 
                 [features]
-                clap = ["clap/derive"]
                 default = ["clap"]
+                clap = ["clap/derive"]
+                "#
+            )
+        }
+
+        test_format! {
+            #[tokio::test]
+            async fn test_default_feature(
+                r#"
+                [features]
+                wasm = ["tombi-schema-store/wasm"]
+                clap = ["dep:clap"]
+                default = ["clap", "native"]
+                native = ["tombi-schema-store/native"]
+                "#,
+                cargo_schema_path(),
+            ) -> Ok(
+                r#"
+                [features]
+                default = ["clap", "native"]
+                clap = ["dep:clap"]
+                native = ["tombi-schema-store/native"]
+                wasm = ["tombi-schema-store/wasm"]
                 "#
             )
         }
@@ -383,6 +514,31 @@ mod table_keys_order {
             )
         }
 
+        test_format! {
+            #[tokio::test]
+            async fn test_cargo_dependencies_trailing_comma_with_comment_directive(
+                r#"
+                [dependencies]
+                serde = { features = [
+                  # tombi: format.rules.array-values-order.disabled = true
+
+                  "std", "derive",
+                ], version = "^1.0.0" }
+                "#,
+                cargo_schema_path(),
+            ) -> Ok(
+                r#"
+                [dependencies]
+                serde = { version = "^1.0.0", features = [
+                  # tombi: format.rules.array-values-order.disabled = true
+
+                  "std",
+                  "derive",
+                ] }
+                "#
+            )
+        }
+
         test_format! {
             #[tokio::test]
             async fn test_workspace_dependencies(
@@ -446,7 +602,7 @@ mod table_keys_order {
                 include = ["*.toml"]
                 path = "pyproject.toml"
                 "#,
-                tombi_schema_path(),
+              tombi_schema_path(),
             ) -> Ok(
                 r#"
                 [[schemas]]
@@ -489,6 +645,68 @@ mod table_keys_order {
                 "#
             )
         }
+
+        test_format! {
+            #[tokio::test]
+            async fn test_comment_directive_sort(
+                r#"
+                # tombi: format.rules.table-keys-order = "descending"
+
+                [aaa]
+                key1 = "value1"
+
+                [bbb]
+                key2 = "value2"
+
+                [ccc]
+                key3 = "value3"
+
+                [ccc.ddd]
+                key4 = "value4"
+                "#,
+            ) -> Ok(r#"
+                # tombi: format.rules.table-keys-order = "descending"
+
+                [ccc]
+                key3 = "value3"
+
+                [ccc.ddd]
+                key4 = "value4"
+
+                [bbb]
+                key2 = "value2"
+
+                [aaa]
+                key1 = "value1"
+                "#
+            )
+        }
+
+        test_format! {
+            #[tokio::test]
+            async fn test_array_of_tables(
+                r#"
+                [[aaa]]
+                key1 = "value1"
+                key2 = "value2"
+
+                [[aaa]]
+                key1 = "value3"
+                key2 = "value4"
+
+                [aaa.key3]
+                key4 = "value5"
+
+                [[aaa]]
+                key1 = "value6"
+                key2 = "value7"
+
+                [[aaa]]
+                key1 = "value8"
+                key2 = "value9"
+                "#,
+            ) -> Ok(_)
+        }
     }
 
     mod file_schema {
@@ -882,6 +1100,18 @@ mod table_keys_order {
 
     #[macro_export]
     macro_rules! test_format {
+        (
+            #[tokio::test]
+            async fn $name:ident(
+                $source:expr,
+                $schema_path:expr$(,)?
+            ) -> Ok(_)
+        ) => {
+            test_format! {
+                #[tokio::test]
+                async fn _$name($source, Some($schema_path)) -> Ok($source)
+            }
+        };
         (
             #[tokio::test]
             async fn $name:ident(
@@ -895,6 +1125,18 @@ mod table_keys_order {
             }
         };
 
+        (
+            #[tokio::test]
+            async fn $name:ident(
+                $source:expr,
+            ) -> Ok(_)
+        ) => {
+            test_format! {
+                #[tokio::test]
+                async fn _$name($source, Option::<&std::path::Path>::None) -> Ok($source)
+            }
+        };
+
         (
             #[tokio::test]
             async fn $name:ident(
@@ -927,12 +1169,15 @@ mod table_keys_order {
                 let schema_store = SchemaStore::new();
 
                 if let Some(schema_path) = $schema_path {
+                    let path = tombi_uri::Uri::from_file_path(schema_path)
+                        .unwrap()
+                        .to_string();
                     // Load schemas
                     schema_store
                         .load_config_schemas(
                             &[tombi_config::Schema::Root(tombi_config::RootSchema {
                                 toml_version: None,
-                                path: schema_path.to_string_lossy().to_string(),
+                                path,
                                 include: vec!["*.toml".to_string()],
                             })],
                             None,
