@@ -1,16 +1,15 @@
+mod diagnostic;
 mod error;
 mod lint;
 mod linter;
 mod rule;
-mod severity;
 
+pub use diagnostic::{Diagnostic, DiagnosticKind};
 pub use error::{Error, ErrorKind};
 use lint::Lint;
 pub use linter::Linter;
 use rule::Rule;
-pub use severity::{Severity, SeverityKind};
 pub use tombi_config::LintOptions;
-use tombi_diagnostic::Diagnostic;
 
 #[cfg(test)]
 #[macro_export]
@@ -18,12 +17,33 @@ macro_rules! test_lint {
     (
         #[test]
         fn $name:ident(
-            $source:expr,
+            $source:expr$(,)?
         ) -> Ok(_);
     ) => {
         test_lint! {
             #[test]
-            fn _$name($source, Option::<std::path::PathBuf>::None) -> Ok(_);
+            fn _$name(
+                $source,
+                Option::<std::path::PathBuf>::None,
+                TomlVersion::default(),
+            ) -> Ok(_);
+        }
+    };
+
+    (
+        #[test]
+        fn $name:ident(
+            $source:expr,
+            TomlVersion($toml_version:expr)$(,)?
+        ) -> Ok(_);
+    ) => {
+        test_lint! {
+            #[test]
+            fn _$name(
+                $source,
+                Option::<std::path::PathBuf>::None,
+                $toml_version,
+            ) -> Ok(_);
         }
     };
 
@@ -36,7 +56,11 @@ macro_rules! test_lint {
     ) => {
         test_lint! {
             #[test]
-            fn _$name($source, Some($schema_path)) -> Ok(_);
+            fn _$name(
+                $source,
+                Some($schema_path),
+                TomlVersion::default(),
+            ) -> Ok(_);
         }
     };
 
@@ -44,7 +68,8 @@ macro_rules! test_lint {
         #[test]
         fn _$name:ident(
             $source:expr,
-            $schema_path:expr$(,)?
+            $schema_path:expr,
+            $toml_version:expr,
         ) -> Ok(_);
     ) => {
         #[tokio::test]
@@ -74,7 +99,7 @@ macro_rules! test_lint {
             let source_path = tombi_test_lib::project_root_path().join("test.toml");
             let options = $crate::LintOptions::default();
             let linter = $crate::Linter::new(
-                TomlVersion::default(),
+                $toml_version,
                 &options,
                 Some(itertools::Either::Right(source_path.as_path())),
                 &schema_store,
@@ -102,7 +127,11 @@ macro_rules! test_lint {
     ) => {
         test_lint! {
             #[test]
-            fn _$name($source, Some($schema_path)) -> Err([$($error.to_string()),*]);
+            fn _$name(
+                $source,
+                Some($schema_path),
+                TomlVersion::default(),
+            ) -> Err([$($error.to_string()),*]);
         }
     };
 
@@ -114,7 +143,28 @@ macro_rules! test_lint {
     ) => {
         test_lint! {
             #[test]
-            fn _$name($source, Option::<std::path::PathBuf>::None) -> Err([$($error.to_string()),*]);
+            fn _$name(
+                $source,
+                Option::<std::path::PathBuf>::None,
+                TomlVersion::default(),
+            ) -> Err([$($error.to_string()),*]);
+        }
+    };
+
+    (
+        #[test]
+        fn $name:ident(
+            $source:expr,
+            TomlVersion($toml_version:expr),
+        ) -> Err([$( $error:expr ),*$(,)?]);
+    ) => {
+        test_lint! {
+            #[test]
+            fn _$name(
+                $source,
+                Option::<std::path::PathBuf>::None,
+                $toml_version,
+            ) -> Err([$($error.to_string()),*]);
         }
     };
 
@@ -122,12 +172,14 @@ macro_rules! test_lint {
         #[test]
         fn _$name:ident(
             $source:expr,
-            $schema_path:expr$(,)?
+            $schema_path:expr,
+            $toml_version:expr,
         ) -> Err([$( $error:expr ),*$(,)?]);
     ) => {
         #[tokio::test]
         async fn $name() {
             use tombi_config::TomlVersion;
+            use itertools::Itertools;
 
             tombi_test_lib::init_tracing();
 
@@ -152,7 +204,7 @@ macro_rules! test_lint {
             let source_path = tombi_test_lib::project_root_path().join("test.toml");
             let options = $crate::LintOptions::default();
             let linter = $crate::Linter::new(
-                TomlVersion::default(),
+                $toml_version,
                 &options,
                 Some(itertools::Either::Right(source_path.as_path())),
                 &schema_store,
@@ -168,7 +220,7 @@ macro_rules! test_lint {
                         errors
                             .into_iter()
                             .map(|error| error.message().to_string())
-                            .collect::<Vec<_>>(),
+                            .collect_vec(),
                         [$($error.to_string()),*].into_iter().collect::<Vec<String>>()
                     );
                 }
@@ -206,8 +258,8 @@ mod tests {
                 aaa = 1
                 "#,
                 cargo_schema_path(),
-            ) -> Err([tombi_validator::WarningKind::StrictAdditionalProperties {
-                accessors: tombi_schema_store::SchemaAccessors::new(vec![
+            ) -> Err([tombi_validator::DiagnosticKind::StrictAdditionalKeys {
+                accessors: tombi_schema_store::SchemaAccessors::from(vec![
                     tombi_schema_store::SchemaAccessor::Key("workspace".to_string()),
                 ]),
                 schema_uri: tombi_schema_store::SchemaUri::from_file_path(cargo_schema_path()).unwrap(),
@@ -223,7 +275,49 @@ mod tests {
                 bbb = 1
                 "#,
                 cargo_schema_path(),
-            ) -> Err([tombi_validator::ErrorKind::KeyNotAllowed { key: "aaa".to_string() }]);
+            ) -> Err([tombi_validator::DiagnosticKind::KeyNotAllowed { key: "aaa".to_string() }]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_package_name_wrong_type(
+                r#"
+                [package]
+                name = 1
+                "#,
+                cargo_schema_path(),
+            ) -> Err([tombi_validator::DiagnosticKind::TypeMismatch {
+                expected: tombi_schema_store::ValueType::String,
+                actual: tombi_document_tree::ValueType::Integer,
+            }]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_package_name_wrong_type_with_comment_directive_disabled_eq_true(
+                r#"
+                [package]
+                name = 1 # tombi: lint.rules.type-mismatch.disabled = true
+                "#,
+                cargo_schema_path(),
+            ) -> Ok(_);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_package_name_wrong_type_with_wrong_comment_directive_disabled_eq_true(
+                r#"
+                [package]
+                name = 1 # tombi: lint.rules.type-mism.disabled = true
+                "#,
+                cargo_schema_path(),
+            ) -> Err([
+                tombi_validator::DiagnosticKind::KeyNotAllowed { key: "type-mism".to_string() },
+                tombi_validator::DiagnosticKind::TypeMismatch {
+                    expected: tombi_schema_store::ValueType::String,
+                    actual: tombi_document_tree::ValueType::Integer,
+                }
+            ]);
         }
     }
 
@@ -250,11 +344,11 @@ mod tests {
                 "#,
                 tombi_schema_path(),
             ) -> Err([
-                tombi_validator::WarningKind::Deprecated(tombi_schema_store::SchemaAccessors::new(vec![
+                tombi_validator::DiagnosticKind::DeprecatedValue(tombi_schema_store::SchemaAccessors::from(vec![
                     tombi_schema_store::SchemaAccessor::Key("schemas".to_string()),
                     tombi_schema_store::SchemaAccessor::Index,
                     tombi_schema_store::SchemaAccessor::Key("root-keys".to_string()),
-                ])),
+                ]), "\"tool.taskipy\"".to_string()),
             ]);
         }
 
@@ -267,18 +361,10 @@ mod tests {
                 "#,
                 tombi_schema_path(),
             ) -> Err([
-                tombi_validator::ErrorKind::Const {
-                    expected: "\"off\"".to_string(),
+                tombi_validator::DiagnosticKind::Enumerate {
+                    expected: vec!["\"off\"".to_string(), "\"warn\"".to_string(), "\"error\"".to_string()],
                     actual: "\"undefined\"".to_string()
                 },
-                tombi_validator::ErrorKind::Const {
-                    expected: "\"warn\"".to_string(),
-                    actual: "\"undefined\"".to_string()
-                },
-                tombi_validator::ErrorKind::Const {
-                    expected: "\"error\"".to_string(),
-                    actual: "\"undefined\"".to_string()
-                }
             ]);
         }
     }
@@ -322,6 +408,7 @@ mod tests {
     }
 
     mod non_schema {
+        use std::str::FromStr;
         use tombi_schema_store::SchemaUri;
 
         use super::*;
@@ -333,7 +420,108 @@ mod tests {
                 "" = 1
                 "#,
             ) -> Err([
-                crate::SeverityKind::KeyEmpty
+                crate::DiagnosticKind::KeyEmpty
+            ]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_empty_document_with_dangling_value_comment_directive(
+                r#"
+                # tombi: format.rules.table-keys-order = "descending"
+                "#,
+            ) -> Ok(_);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_key_value_with_dangling_value_comment_directive(
+                r#"
+                # tombi: format.rules.table-keys-order = "descending"
+
+                key = "value"
+                "#,
+            ) -> Ok(_);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_table_with_dangling_value_comment_directive(
+                r#"
+                # tombi: format.rules.table-keys-order = "descending"
+
+                [aaa]
+                "#,
+            ) -> Ok(_);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_table_warning_empty(
+                r#"
+                [aaa]
+                "" = 1
+                "#,
+            ) -> Err([
+                crate::DiagnosticKind::KeyEmpty
+            ]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_array_of_table_warning_empty(
+                r#"
+                [[aaa]]
+                "" = 1
+                "#,
+            ) -> Err([
+                crate::DiagnosticKind::KeyEmpty
+            ]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_inline_table_warning_empty(
+                r#"
+                key = { "" = 1 }
+                "#,
+            ) -> Err([
+                crate::DiagnosticKind::KeyEmpty
+            ]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_nested_inline_table_warning_empty(
+                r#"
+                key = { key2 = { "" = 1 } }
+                "#,
+            ) -> Err([
+                crate::DiagnosticKind::KeyEmpty
+            ]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_table_inline_table_warning_empty(
+                r#"
+                [array]
+                key = { "" = 1 }
+                "#,
+            ) -> Err([
+                crate::DiagnosticKind::KeyEmpty
+            ]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_array_of_table_inline_table_warning_empty(
+                r#"
+                [[array]]
+                key = { "" = 1 }
+                "#,
+            ) -> Err([
+                crate::DiagnosticKind::KeyEmpty
             ]);
         }
 
@@ -351,15 +539,33 @@ mod tests {
                 orange.color = "orange"
                 "#,
             ) -> Err([
-                crate::SeverityKind::DottedKeysOutOfOrder,
-                crate::SeverityKind::DottedKeysOutOfOrder,
-                crate::SeverityKind::DottedKeysOutOfOrder,
-                crate::SeverityKind::DottedKeysOutOfOrder,
-                crate::SeverityKind::DottedKeysOutOfOrder,
-                crate::SeverityKind::DottedKeysOutOfOrder
+                crate::DiagnosticKind::DottedKeysOutOfOrder,
+                crate::DiagnosticKind::DottedKeysOutOfOrder,
+                crate::DiagnosticKind::DottedKeysOutOfOrder,
+                crate::DiagnosticKind::DottedKeysOutOfOrder,
+                crate::DiagnosticKind::DottedKeysOutOfOrder,
+                crate::DiagnosticKind::DottedKeysOutOfOrder
             ]);
         }
 
+        test_lint! {
+            #[test]
+            fn test_dotted_keys_out_of_order_with_comment_directive_table_keys_order_disabled_eq_true(
+                r#"
+                # tombi: format.rules.table-keys-order.disabled = true
+
+                apple.type = "fruit"
+                orange.type = "fruit"
+
+                apple.skin = "thin"
+                orange.skin = "thick"
+
+                apple.color = "red"
+                orange.color = "orange"
+                "#,
+            ) -> Ok(_);
+        }
+
         test_lint! {
             #[test]
             fn test_schema_uri(
@@ -386,7 +592,7 @@ mod tests {
                 "#,
             ) -> Err([
                 tombi_schema_store::Error::SchemaFetchFailed{
-                    schema_uri: SchemaUri::parse("https://does-not-exist.co.jp").unwrap(),
+                    schema_uri: SchemaUri::from_str("https://does-not-exist.co.jp").unwrap(),
                     reason: "error sending request for url (https://does-not-exist.co.jp/)".to_string(),
                 }
             ]);
@@ -430,5 +636,33 @@ mod tests {
                 }
             ]);
         }
+
+        test_lint! {
+            #[test]
+            fn test_tombi_document_comment_directive_lint_not_exist_eq_true(
+                r#"
+                #:tombi lint.not-exist = true
+                "#,
+            ) -> Err([
+                tombi_validator::DiagnosticKind::KeyNotAllowed { key: "not-exist".to_string() }
+            ]);
+        }
+
+        test_lint! {
+            #[test]
+            fn test_tombi_document_comment_directive_lint_disable_eq_true(
+                r#"
+                #:tombi lint.disable = true
+                "#,
+            ) -> Err([
+                tombi_validator::DiagnosticKind::DeprecatedValue(
+                    tombi_schema_store::SchemaAccessors::from(vec![
+                        tombi_schema_store::SchemaAccessor::Key("lint".to_string()),
+                        tombi_schema_store::SchemaAccessor::Key("disable".to_string()),
+                    ]),
+                    "true".to_string()
+                )
+            ]);
+        }
     }
 }
