@@ -24,7 +24,6 @@ use local_time::type_hint_local_time;
 use offset_date_time::type_hint_offset_date_time;
 pub use one_of::find_one_of_completion_items;
 use string::type_hint_string;
-use tombi_config::TomlVersion;
 use tombi_future::Boxable;
 use tombi_schema_store::{
     Accessor, ArraySchema, BooleanSchema, CurrentSchema, FloatSchema, IntegerSchema,
@@ -55,13 +54,90 @@ impl FindCompletionContents for tombi_document_tree::Value {
 
         async move {
             match self {
-                Self::Boolean(_)
-                | Self::Integer(_)
-                | Self::Float(_)
-                | Self::OffsetDateTime(_)
-                | Self::LocalDateTime(_)
-                | Self::LocalDate(_)
-                | Self::LocalTime(_) => Vec::with_capacity(0),
+                Self::Boolean(boolean) => {
+                    boolean
+                        .find_completion_contents(
+                            position,
+                            keys,
+                            accessors,
+                            current_schema,
+                            schema_context,
+                            completion_hint,
+                        )
+                        .await
+                }
+                Self::Integer(integer) => {
+                    integer
+                        .find_completion_contents(
+                            position,
+                            keys,
+                            accessors,
+                            current_schema,
+                            schema_context,
+                            completion_hint,
+                        )
+                        .await
+                }
+                Self::Float(float) => {
+                    float
+                        .find_completion_contents(
+                            position,
+                            keys,
+                            accessors,
+                            current_schema,
+                            schema_context,
+                            completion_hint,
+                        )
+                        .await
+                }
+                Self::OffsetDateTime(offset_date_time) => {
+                    offset_date_time
+                        .find_completion_contents(
+                            position,
+                            keys,
+                            accessors,
+                            current_schema,
+                            schema_context,
+                            completion_hint,
+                        )
+                        .await
+                }
+                Self::LocalDateTime(local_date_time) => {
+                    local_date_time
+                        .find_completion_contents(
+                            position,
+                            keys,
+                            accessors,
+                            current_schema,
+                            schema_context,
+                            completion_hint,
+                        )
+                        .await
+                }
+                Self::LocalDate(local_date) => {
+                    local_date
+                        .find_completion_contents(
+                            position,
+                            keys,
+                            accessors,
+                            current_schema,
+                            schema_context,
+                            completion_hint,
+                        )
+                        .await
+                }
+                Self::LocalTime(local_time) => {
+                    local_time
+                        .find_completion_contents(
+                            position,
+                            keys,
+                            accessors,
+                            current_schema,
+                            schema_context,
+                            completion_hint,
+                        )
+                        .await
+                }
                 Self::String(string_value) => {
                     string_value
                         .find_completion_contents(
@@ -119,19 +195,13 @@ impl FindCompletionContents for tombi_document_tree::Value {
                                 if range.end < position =>
                             {
                                 vec![CompletionContent::new_type_hint_key(
-                                    &last_key.to_raw_text(schema_context.toml_version),
+                                    &last_key.value,
                                     last_key.range(),
                                     None,
                                     completion_hint,
                                 )]
                             }
-                            _ => type_hint_value(
-                                last_key,
-                                position,
-                                schema_context.toml_version,
-                                None,
-                                completion_hint,
-                            ),
+                            _ => type_hint_value(last_key, position, None, completion_hint),
                         }
                     }
                 },
@@ -144,7 +214,6 @@ impl FindCompletionContents for tombi_document_tree::Value {
 pub fn type_hint_value(
     key: Option<&tombi_document_tree::Key>,
     position: tombi_text::Position,
-    toml_version: TomlVersion,
     schema_uri: Option<&SchemaUri>,
     completion_hint: Option<CompletionHint>,
 ) -> Vec<CompletionContent> {
@@ -170,11 +239,16 @@ pub fn type_hint_value(
             Some(
                 CompletionHint::DotTrigger { range, .. } | CompletionHint::EqualTrigger { range },
             ) => range.end == position || range.end <= key.range().start,
-            Some(CompletionHint::InTableHeader | CompletionHint::InArray) | None => true,
+            Some(
+                CompletionHint::InTableHeader
+                | CompletionHint::InArray { .. }
+                | CompletionHint::Comma { .. },
+            )
+            | None => true,
         };
         if need_key_hint {
             completion_contents.push(CompletionContent::new_type_hint_key(
-                &key.to_raw_text(toml_version),
+                &key.value,
                 key.range(),
                 schema_uri,
                 completion_hint,
