@@ -1,19 +1,21 @@
 mod all_of;
 mod any_of;
+mod comment;
 mod one_of;
 mod value;
 
 use std::{borrow::Cow, ops::Deref};
 
+pub use comment::get_tombi_document_comment_directive_type_definition;
 use tombi_schema_store::{CurrentSchema, SchemaUri};
 
 pub async fn get_type_definition(
-    tree: &tombi_document_tree::DocumentTree,
+    document_tree: &tombi_document_tree::DocumentTree,
     position: tombi_text::Position,
     keys: &[tombi_document_tree::Key],
     schema_context: &tombi_schema_store::SchemaContext<'_>,
 ) -> Option<TypeDefinition> {
-    let table = tree.deref();
+    let table = document_tree.deref();
     match schema_context.root_schema {
         Some(document_schema) => {
             let current_schema =
@@ -40,7 +42,12 @@ pub async fn get_type_definition(
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 pub struct TypeDefinition {
     pub schema_uri: SchemaUri,
+
     pub schema_accessors: Vec<tombi_schema_store::SchemaAccessor>,
+
+    /// The range of the schema definition.
+    ///
+    /// It's JSON Schema file range, not TOML file range.
     pub range: tombi_text::Range,
 }
 
