@@ -6,7 +6,9 @@ use tower_lsp::lsp_types::request::GotoTypeDefinitionParams;
 use crate::{
     backend::Backend,
     config_manager::ConfigSchemaStore,
-    goto_type_definition::{get_type_definition, TypeDefinition},
+    goto_type_definition::{
+        get_tombi_document_comment_directive_type_definition, get_type_definition, TypeDefinition,
+    },
     handler::hover::get_hover_keys_with_range,
 };
 
@@ -54,17 +56,26 @@ pub async fn handle_goto_type_definition(
         return Ok(Default::default());
     };
 
+    if let Some(type_definition) =
+        get_tombi_document_comment_directive_type_definition(&root, position).await
+    {
+        return Ok(Some(vec![tombi_extension::DefinitionLocation {
+            uri: type_definition.schema_uri.into(),
+            range: type_definition.range,
+        }]));
+    }
+
     let source_schema = schema_store
         .resolve_source_schema_from_ast(&root, Some(Either::Left(&text_document_uri)))
         .await
         .ok()
         .flatten();
 
-    let document_tombi_comment_directive =
-        tombi_comment_directive::get_document_tombi_comment_directive(&root).await;
+    let tombi_document_comment_directive =
+        tombi_validator::comment_directive::get_tombi_document_comment_directive(&root).await;
     let (toml_version, _) = backend
         .source_toml_version(
-            document_tombi_comment_directive,
+            tombi_document_comment_directive,
             source_schema.as_ref(),
             &config,
         )
