@@ -1,9 +1,10 @@
 use std::borrow::Cow;
 
-use itertools::Itertools;
 use tombi_future::Boxable;
 use tombi_schema_store::{Accessor, CurrentSchema, SchemaUri};
 
+use crate::HoverContent;
+
 use super::{
     constraints::ValueConstraints,
     display_value::{DisplayValue, GetEnumerate},
@@ -19,13 +20,24 @@ pub fn get_one_of_hover_content<'a: 'b, 'b, T>(
     schema_uri: &'a SchemaUri,
     definitions: &'a tombi_schema_store::SchemaDefinitions,
     schema_context: &'a tombi_schema_store::SchemaContext,
-) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>>
+) -> tombi_future::BoxFuture<'b, Option<HoverContent>>
 where
-    T: GetHoverContent + tombi_document_tree::ValueImpl + tombi_validator::Validate + Sync + Send,
+    T: GetHoverContent
+        + tombi_document_tree::ValueImpl
+        + tombi_validator::Validate
+        + Sync
+        + Send
+        + std::fmt::Debug,
 {
+    tracing::trace!("value = {:?}", value);
+    tracing::trace!("keys = {:?}", keys);
+    tracing::trace!("accessors = {:?}", accessors);
+    tracing::trace!("one_of_schema = {:?}", one_of_schema);
+    tracing::trace!("schema_uri = {:?}", schema_uri);
+
     async move {
-        let mut one_hover_contents = ahash::AHashSet::new();
-        let mut valid_hover_contents = ahash::AHashSet::new();
+        let mut one_hover_value_contents = ahash::AHashSet::new();
+        let mut valid_hover_value_contents = ahash::AHashSet::new();
         let mut value_type_set = indexmap::IndexSet::new();
         let mut enumerate_values = Vec::new();
         let default = one_of_schema
@@ -74,7 +86,7 @@ where
                 continue;
             };
 
-            if let Some(mut hover_content) = value
+            match value
                 .get_hover_content(
                     position,
                     keys,
@@ -84,56 +96,62 @@ where
                 )
                 .await
             {
-                if hover_content.title.is_none() && hover_content.description.is_none() {
-                    if let Some(title) = &one_of_schema.title {
-                        hover_content.title = Some(title.clone());
-                    }
-                    if let Some(description) = &one_of_schema.description {
-                        hover_content.description = Some(description.clone());
-                    }
-                }
-
-                if keys.is_empty() && accessors == hover_content.accessors.as_ref() {
-                    hover_content.value_type = value_type.clone();
-                }
-
-                if current_schema.value_schema.value_type().await
-                    == tombi_schema_store::ValueType::Array
-                    && hover_content.value_type != tombi_schema_store::ValueType::Array
-                {
-                    return Some(hover_content);
-                }
-
-                match value
-                    .validate(
-                        &accessors
-                            .iter()
-                            .map(|accessor| accessor.into())
-                            .collect_vec(),
-                        Some(&current_schema),
-                        schema_context,
-                    )
-                    .await
-                {
-                    Ok(()) => {
-                        valid_hover_contents.insert(hover_content.clone());
-                    }
-                    Err(errors)
-                        if errors
-                            .iter()
-                            .all(|error| error.level() == tombi_diagnostic::Level::WARNING) =>
+                Some(HoverContent::Value(mut hover_value_content)) => {
+                    if hover_value_content.title.is_none()
+                        && hover_value_content.description.is_none()
                     {
-                        valid_hover_contents.insert(hover_content.clone());
+                        if let Some(title) = &one_of_schema.title {
+                            hover_value_content.title = Some(title.clone());
+                        }
+                        if let Some(description) = &one_of_schema.description {
+                            hover_value_content.description = Some(description.clone());
+                        }
                     }
-                    _ => {}
-                }
 
-                one_hover_contents.insert(hover_content);
+                    if keys.is_empty() && accessors == hover_value_content.accessors.as_ref() {
+                        hover_value_content.value_type = value_type.clone();
+                    }
+
+                    if current_schema.value_schema.value_type().await
+                        == tombi_schema_store::ValueType::Array
+                        && hover_value_content.value_type != tombi_schema_store::ValueType::Array
+                    {
+                        return Some(HoverContent::Value(hover_value_content));
+                    }
+
+                    match value
+                        .validate(&accessors, Some(&current_schema), schema_context)
+                        .await
+                    {
+                        Ok(()) => {
+                            valid_hover_value_contents.insert(hover_value_content.clone());
+                        }
+                        Err(errors)
+                            if errors
+                                .iter()
+                                .all(|error| error.level() == tombi_diagnostic::Level::WARNING) =>
+                        {
+                            valid_hover_value_contents.insert(hover_value_content.clone());
+                        }
+                        _ => {}
+                    }
+
+                    one_hover_value_contents.insert(hover_value_content);
+                }
+                Some(HoverContent::Directive(hover_content)) => {
+                    return Some(HoverContent::Directive(hover_content));
+                }
+                Some(HoverContent::DirectiveContent(hover_content)) => {
+                    return Some(HoverContent::DirectiveContent(hover_content));
+                }
+                None => {
+                    continue;
+                }
             }
         }
 
-        if one_hover_contents.len() == 1 {
-            one_hover_contents
+        let mut hover_value_content = if one_hover_value_contents.len() == 1 {
+            one_hover_value_contents
                 .into_iter()
                 .next()
                 .map(|mut hover_content| {
@@ -148,8 +166,8 @@ where
 
                     hover_content
                 })
-        } else if valid_hover_contents.len() == 1 {
-            valid_hover_contents
+        } else if valid_hover_value_contents.len() == 1 {
+            valid_hover_value_contents
                 .into_iter()
                 .next()
                 .map(|mut hover_content| {
@@ -168,21 +186,22 @@ where
             Some(HoverValueContent {
                 title: None,
                 description: None,
-                accessors: tombi_schema_store::Accessors::new(accessors.to_vec()),
+                accessors: tombi_schema_store::Accessors::from(accessors.to_vec()),
                 value_type: value.value_type().into(),
                 constraints: None,
                 schema_uri: Some(schema_uri.to_owned()),
                 range: None,
             })
-        }
-        .map(|mut hover_content| {
+        };
+
+        if let Some(hover_value_content) = hover_value_content.as_mut() {
             if let Some(default) = default {
-                if let Some(constraints) = hover_content.constraints.as_mut() {
+                if let Some(constraints) = hover_value_content.constraints.as_mut() {
                     if constraints.default.is_none() {
                         constraints.default = Some(default);
                     }
                 } else {
-                    hover_content.constraints = Some(ValueConstraints {
+                    hover_value_content.constraints = Some(ValueConstraints {
                         default: Some(default),
                         ..Default::default()
                     });
@@ -190,18 +209,18 @@ where
             }
 
             if !enumerate_values.is_empty() {
-                if let Some(constraints) = hover_content.constraints.as_mut() {
+                if let Some(constraints) = hover_value_content.constraints.as_mut() {
                     constraints.enumerate = Some(enumerate_values);
                 } else {
-                    hover_content.constraints = Some(ValueConstraints {
+                    hover_value_content.constraints = Some(ValueConstraints {
                         enumerate: Some(enumerate_values),
                         ..Default::default()
                     });
                 }
             }
+        }
 
-            hover_content
-        })
+        hover_value_content.map(HoverContent::Value)
     }
     .boxed()
 }
@@ -214,7 +233,7 @@ impl GetHoverContent for tombi_schema_store::OneOfSchema {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
         async move {
             let Some(current_schema) = current_schema else {
                 unreachable!("schema must be provided");
@@ -222,9 +241,19 @@ impl GetHoverContent for tombi_schema_store::OneOfSchema {
 
             let mut title_description_set = ahash::AHashSet::new();
             let mut value_type_set = indexmap::IndexSet::new();
+            let mut enumerate_values = Vec::new();
+            let default = self
+                .default
+                .as_ref()
+                .and_then(|default| DisplayValue::try_from(default).ok());
 
             for referable_schema in self.schemas.write().await.iter_mut() {
-                let Ok(Some(CurrentSchema { value_schema, .. })) = referable_schema
+                let Ok(Some(CurrentSchema {
+                    value_schema,
+                    schema_uri,
+                    definitions,
+                    ..
+                })) = referable_schema
                     .resolve(
                         current_schema.schema_uri.clone(),
                         current_schema.definitions.clone(),
@@ -232,7 +261,7 @@ impl GetHoverContent for tombi_schema_store::OneOfSchema {
                     )
                     .await
                 else {
-                    return None;
+                    continue;
                 };
                 if value_schema.title().is_some() || value_schema.description().is_some() {
                     title_description_set.insert((
@@ -241,6 +270,14 @@ impl GetHoverContent for tombi_schema_store::OneOfSchema {
                     ));
                 }
                 value_type_set.insert(value_schema.value_type().await);
+
+                if let Some(values) = value_schema
+                    .as_ref()
+                    .get_enumerate(&schema_uri, &definitions, schema_context)
+                    .await
+                {
+                    enumerate_values.extend(values);
+                }
             }
 
             let (mut title, mut description) = if title_description_set.len() == 1 {
@@ -264,15 +301,41 @@ impl GetHoverContent for tombi_schema_store::OneOfSchema {
                 tombi_schema_store::ValueType::OneOf(value_type_set.into_iter().collect())
             };
 
-            Some(HoverValueContent {
+            let mut hover_value_content = HoverValueContent {
                 title,
                 description,
-                accessors: tombi_schema_store::Accessors::new(accessors.to_vec()),
+                accessors: tombi_schema_store::Accessors::from(accessors.to_vec()),
                 value_type,
                 constraints: None,
                 schema_uri: Some(current_schema.schema_uri.as_ref().to_owned()),
                 range: None,
-            })
+            };
+
+            if let Some(default) = default {
+                if let Some(constraints) = hover_value_content.constraints.as_mut() {
+                    if constraints.default.is_none() {
+                        constraints.default = Some(default);
+                    }
+                } else {
+                    hover_value_content.constraints = Some(ValueConstraints {
+                        default: Some(default),
+                        ..Default::default()
+                    });
+                }
+            }
+
+            if !enumerate_values.is_empty() {
+                if let Some(constraints) = hover_value_content.constraints.as_mut() {
+                    constraints.enumerate = Some(enumerate_values);
+                } else {
+                    hover_value_content.constraints = Some(ValueConstraints {
+                        enumerate: Some(enumerate_values),
+                        ..Default::default()
+                    });
+                }
+            }
+
+            Some(HoverContent::Value(hover_value_content))
         }
         .boxed()
     }
