@@ -12,7 +12,9 @@ mod table;
 use tombi_future::Boxable;
 use tombi_schema_store::{Accessor, CurrentSchema, ValueSchema};
 
-use super::{GetHoverContent, HoverValueContent};
+use crate::HoverContent;
+
+use super::GetHoverContent;
 
 impl GetHoverContent for tombi_document_tree::Value {
     fn get_hover_content<'a: 'b, 'b>(
@@ -22,7 +24,12 @@ impl GetHoverContent for tombi_document_tree::Value {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
+        tracing::trace!("self = {:?}", self);
+        tracing::trace!("keys = {:?}", keys);
+        tracing::trace!("accessors = {:?}", accessors);
+        tracing::trace!("current_schema = {:?}", current_schema);
+
         async move {
             match self {
                 Self::Boolean(boolean) => {
@@ -136,20 +143,26 @@ impl GetHoverContent for tombi_document_tree::Value {
                         .await
                 }
                 Self::Incomplete { range } => match current_schema {
-                    Some(current_schema) => current_schema
-                        .value_schema
-                        .get_hover_content(
-                            position,
-                            keys,
-                            accessors,
-                            Some(current_schema),
-                            schema_context,
-                        )
-                        .await
-                        .map(|mut hover_content| {
-                            hover_content.range = Some(*range);
-                            hover_content
-                        }),
+                    Some(current_schema) => {
+                        let mut hover_content = current_schema
+                            .value_schema
+                            .get_hover_content(
+                                position,
+                                keys,
+                                accessors,
+                                Some(current_schema),
+                                schema_context,
+                            )
+                            .await;
+
+                        if let Some(HoverContent::Value(hover_value_content)) =
+                            hover_content.as_mut()
+                        {
+                            hover_value_content.range = Some(*range);
+                        }
+
+                        hover_content
+                    }
                     None => None,
                 },
             }
@@ -166,7 +179,7 @@ impl GetHoverContent for ValueSchema {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
         async move {
             match self {
                 Self::Boolean(boolean_schema) => {
