@@ -1,7 +1,9 @@
 pub mod backend;
 pub mod code_action;
+mod comment_directive;
 mod completion;
 mod config_manager;
+mod diagnostic;
 mod document;
 mod goto_definition;
 mod goto_type_definition;
@@ -10,6 +12,11 @@ mod hover;
 mod semantic_tokens;
 
 pub use backend::Backend;
+pub(crate) use comment_directive::{
+    DOCUMENT_SCHEMA_DIRECTIVE_DESCRIPTION, DOCUMENT_SCHEMA_DIRECTIVE_TITLE,
+    DOCUMENT_TOMBI_DIRECTIVE_DESCRIPTION, DOCUMENT_TOMBI_DIRECTIVE_TITLE,
+};
+pub use hover::HoverContent;
 
 /// Run TOML Language Server
 #[derive(Debug)]
