@@ -293,7 +293,7 @@ mod document_link_tests {
                     tooltip: tombi_extension_cargo::DocumentLinkToolTip::CargoToml,
                 },
                 {
-                    path: project_root_path().join("crates/tombi-ast/Cargo.toml"),
+                    path: project_root_path().join("crates/tombi-accessor/Cargo.toml"),
                     range: 8:12..8:20,
                     tooltip: tombi_extension_cargo::DocumentLinkToolTip::CargoTomlFirstMember,
                 },
@@ -400,6 +400,7 @@ macro_rules! test_document_link {
         #[tokio::test]
         async fn $name() -> Result<(), Box<dyn std::error::Error>> {
             // Use handler functions from tombi_lsp
+            use itertools::Itertools;
             use tombi_lsp::handler::{handle_did_open, handle_document_link};
             use tombi_lsp::Backend;
             use tower_lsp::{
@@ -457,7 +458,7 @@ macro_rules! test_document_link {
                             });
                             document_link
                         })
-                        .collect::<Vec<_>>()
+                        .collect_vec()
                 })
             });
 
