@@ -1,7 +1,7 @@
 use tombi_syntax::T;
 
 use super::{Parse, Parser};
-use crate::parse::{leading_comments, tailing_comment};
+use crate::parse::{leading_comments, trailing_comment};
 
 impl Parse for tombi_ast::Comma {
     fn parse(p: &mut Parser<'_>) {
@@ -12,7 +12,7 @@ impl Parse for tombi_ast::Comma {
         assert!(p.at(T![,]));
 
         p.eat(T![,]);
-        tailing_comment(p);
+        trailing_comment(p);
         m.complete(p, T!(,));
     }
 }
