@@ -3,15 +3,16 @@ use std::{borrow::Cow, ops::Deref, str::FromStr, sync::Arc};
 use crate::{
     get_tombi_schemastore_content, http_client::HttpClient, json::JsonCatalog, AllOfSchema,
     AnyOfSchema, CatalogUri, DocumentSchema, OneOfSchema, SchemaAccessor, SchemaAccessors,
-    SchemaUri, SourceSchema, ValueSchema,
+    SourceSchema, ValueSchema,
 };
 use ahash::AHashMap;
-use itertools::Either;
+use itertools::{Either, Itertools};
 use tokio::sync::RwLock;
-use tombi_ast::DocumentSchemaCommentDirective;
+use tombi_ast::SchemaDocumentCommentDirective;
 use tombi_cache::{get_cache_file_path, read_from_cache, refresh_cache, save_to_cache};
 use tombi_config::{Schema, SchemaOptions};
 use tombi_future::{BoxFuture, Boxable};
+use tombi_uri::SchemaUri;
 
 #[derive(Debug, Clone)]
 pub struct SchemaStore {
@@ -118,7 +119,7 @@ impl SchemaStore {
                             catalog_path: catalog_path.to_string(),
                         });
                     };
-                    let tagalog_uri = CatalogUri::new(tagalog_uri);
+                    let tagalog_uri = CatalogUri::from(tagalog_uri);
                     self.load_catalog_from_uri(&tagalog_uri).await
                 }))
                 .await;
@@ -143,7 +144,7 @@ impl SchemaStore {
         base_dir_path: Option<&std::path::Path>,
     ) {
         futures::future::join_all(schemas.iter().map(|schema| async move {
-            let schema_uri = if let Ok(schema_uri) = SchemaUri::parse(schema.path()) {
+            let schema_uri = if let Ok(schema_uri) = SchemaUri::from_str(schema.path()) {
                 schema_uri
             } else if let Ok(schema_uri) = match base_dir_path {
                 Some(base_dir_path) => SchemaUri::from_file_path(base_dir_path.join(schema.path())),
@@ -151,11 +152,11 @@ impl SchemaStore {
             } {
                 schema_uri
             } else {
-                tracing::error!("invalid schema path: {}", schema.path());
+                tracing::warn!("Invalid schema path: {}", schema.path());
                 return;
             };
 
-            tracing::debug!("load config schema from: {}", schema_uri);
+            tracing::debug!("Load schema from config: {}", schema_uri);
 
             self.schemas.write().await.push(crate::Schema {
                 url: schema_uri,
@@ -249,7 +250,7 @@ impl SchemaStore {
                 };
 
                 if let Err(err) = save_to_cache(catalog_cache_path.as_deref(), &bytes).await {
-                    tracing::error!("{err}");
+                    tracing::warn!("{err}");
                 }
 
                 match serde_json::from_slice::<crate::json::JsonCatalog>(&bytes) {
@@ -406,7 +407,7 @@ impl SchemaStore {
                 };
 
                 if let Err(err) = save_to_cache(schema_cache_path.as_deref(), &bytes).await {
-                    tracing::error!("{err}");
+                    tracing::warn!("{err}");
                 }
 
                 Ok(Some(
@@ -454,25 +455,22 @@ impl SchemaStore {
             None => return Ok(None),
         };
         let document_schema = DocumentSchema::new(object, schema_uri.clone());
-        if let Some(value_schema) = &document_schema.value_schema {
-            match value_schema {
-                ValueSchema::AllOf(AllOfSchema { schemas, .. })
-                | ValueSchema::AnyOf(AnyOfSchema { schemas, .. })
-                | ValueSchema::OneOf(OneOfSchema { schemas, .. }) => {
-                    for referable_schema in schemas.write().await.iter_mut() {
-                        if let Err(err) = referable_schema
-                            .resolve(
-                                Cow::Borrowed(schema_uri),
-                                Cow::Borrowed(&document_schema.definitions),
-                                self,
-                            )
-                            .await
-                        {
-                            return Err(err);
-                        }
-                    }
+        if let Some(
+            ValueSchema::AllOf(AllOfSchema { schemas, .. })
+            | ValueSchema::AnyOf(AnyOfSchema { schemas, .. })
+            | ValueSchema::OneOf(OneOfSchema { schemas, .. }),
+        ) = &document_schema.value_schema
+        {
+            {
+                for referable_schema in schemas.write().await.iter_mut() {
+                    referable_schema
+                        .resolve(
+                            Cow::Borrowed(schema_uri),
+                            Cow::Borrowed(&document_schema.definitions),
+                            self,
+                        )
+                        .await?;
                 }
-                _ => {}
             }
         }
 
@@ -533,8 +531,8 @@ impl SchemaStore {
             None => None,
         };
 
-        if let Some(DocumentSchemaCommentDirective { uri, uri_range, .. }) =
-            root.document_schema_comment_directive(source_path.as_deref())
+        if let Some(SchemaDocumentCommentDirective { uri, uri_range, .. }) =
+            root.schema_document_comment_directive(source_path.as_deref())
         {
             let schema_uri = match uri {
                 Ok(schema_uri) => schema_uri,
@@ -548,7 +546,7 @@ impl SchemaStore {
                 }
             };
             return self
-                .try_get_source_schema_from_remote_url(&SchemaUri::new(schema_uri))
+                .try_get_source_schema_from_remote_url(&SchemaUri::from(schema_uri))
                 .await
                 .map_err(|err| (err, uri_range));
         }
@@ -584,7 +582,7 @@ impl SchemaStore {
                         .unwrap_or(false)
                 })
             })
-            .collect::<Vec<_>>();
+            .collect_vec();
 
         let mut source_schema: Option<SourceSchema> = None;
         for matching_schema in matching_schemas {
@@ -638,11 +636,11 @@ impl SchemaStore {
                     },
                 },
                 Ok(None) => {
-                    tracing::error!("failed to find document schema: {}", matching_schema.url);
+                    tracing::warn!("Failed to find document schema: {}", matching_schema.url);
                 }
                 Err(err) => {
-                    tracing::error!(
-                        "failed to get document schema for {url}: {err}",
+                    tracing::warn!(
+                        "Failed to get document schema for {url}: {err}",
                         url = matching_schema.url,
                     );
                 }
@@ -688,7 +686,7 @@ impl SchemaStore {
                 for (accessors, schema_uri) in &source_schema.sub_schema_uri_map {
                     tracing::trace!(
                         "find sub schema {:?} from {}",
-                        SchemaAccessors::new(accessors.clone()),
+                        SchemaAccessors::from(accessors.clone()),
                         schema_uri
                     );
                 }
