@@ -1,5 +1,6 @@
 use std::fmt::Debug;
 
+use tombi_comment_directive::value::CommonLintRules;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_schema_store::CurrentSchema;
 
@@ -7,10 +8,12 @@ use super::Validate;
 
 pub fn validate_all_of<'a: 'b, 'b, T>(
     value: &'a T,
-    accessors: &'a [tombi_schema_store::SchemaAccessor],
+    accessors: &'a [tombi_schema_store::Accessor],
     all_of_schema: &'a tombi_schema_store::AllOfSchema,
     current_schema: &'a CurrentSchema<'a>,
     schema_context: &'a tombi_schema_store::SchemaContext<'a>,
+
+    _common_rules: Option<&'a CommonLintRules>,
 ) -> BoxFuture<'b, Result<(), Vec<tombi_diagnostic::Diagnostic>>>
 where
     T: Validate + Sync + Send + Debug,
@@ -23,14 +26,17 @@ where
 
         let mut schemas = all_of_schema.schemas.write().await;
         for referable_schema in schemas.iter_mut() {
-            let Ok(Some(current_schema)) = referable_schema
+            let current_schema = if let Ok(Some(current_schema)) = referable_schema
                 .resolve(
                     current_schema.schema_uri.clone(),
                     current_schema.definitions.clone(),
                     schema_context.store,
                 )
                 .await
-            else {
+                .inspect_err(|err| tracing::warn!("{err}"))
+            {
+                current_schema
+            } else {
                 continue;
             };
 
