@@ -2,13 +2,13 @@ use std::str::FromStr;
 
 pub const X_TOMBI_TOML_VERSION: &str = "x-tombi-toml-version";
 pub const X_TOMBI_ARRAY_VALUES_ORDER: &str = "x-tombi-array-values-order";
+pub const X_TOMBI_ARRAY_VALUES_ORDER_BY: &str = "x-tombi-array-values-order-by";
 pub const X_TOMBI_TABLE_KEYS_ORDER: &str = "x-tombi-table-keys-order";
 pub const X_TOMBI_STRING_FORMATS: &str = "x-tombi-string-formats";
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, PartialEq, Eq)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 #[cfg_attr(feature = "serde", serde(rename_all = "kebab-case"))]
-#[cfg_attr(feature = "jsonschema", derive(schemars::JsonSchema))]
 pub enum ArrayValuesOrder {
     Ascending,
     Descending,
@@ -38,10 +38,41 @@ impl<'a> TryFrom<&'a str> for ArrayValuesOrder {
     }
 }
 
+#[derive(Debug, Clone, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
+#[cfg_attr(feature = "serde", serde(rename_all = "camelCase"))]
+pub enum ArrayValuesOrderGroup {
+    OneOf(Vec<ArrayValuesOrder>),
+    AnyOf(Vec<ArrayValuesOrder>),
+}
+
+#[derive(Debug, Clone, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
+pub struct ArrayValuesOrderBy(String);
+
+impl std::fmt::Display for ArrayValuesOrderBy {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{}", self.0)
+    }
+}
+
+impl<'a> TryFrom<&'a str> for ArrayValuesOrderBy {
+    type Error = &'a str;
+
+    fn try_from(value: &'a str) -> Result<Self, Self::Error> {
+        Ok(Self(value.to_string()))
+    }
+}
+
+impl PartialEq<ArrayValuesOrderBy> for String {
+    fn eq(&self, other: &ArrayValuesOrderBy) -> bool {
+        self == &other.0
+    }
+}
+
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 #[cfg_attr(feature = "serde", serde(rename_all = "kebab-case"))]
-#[cfg_attr(feature = "jsonschema", derive(schemars::JsonSchema))]
 pub enum TableKeysOrder {
     Ascending,
     Descending,
@@ -74,6 +105,38 @@ impl<'a> TryFrom<&'a str> for TableKeysOrder {
     }
 }
 
+#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
+#[cfg_attr(feature = "serde", serde(rename_all = "kebab-case"))]
+pub enum TableKeysOrderGroupKind {
+    Keys,
+    AdditionalKeys,
+    PatternKeys,
+}
+
+impl std::fmt::Display for TableKeysOrderGroupKind {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            TableKeysOrderGroupKind::Keys => write!(f, "Keys"),
+            TableKeysOrderGroupKind::AdditionalKeys => write!(f, "Additional Keys"),
+            TableKeysOrderGroupKind::PatternKeys => write!(f, "Pattern Keys"),
+        }
+    }
+}
+
+impl<'a> TryFrom<&'a str> for TableKeysOrderGroupKind {
+    type Error = &'a str;
+
+    fn try_from(value: &'a str) -> Result<Self, Self::Error> {
+        match value {
+            "properties" => Ok(TableKeysOrderGroupKind::Keys),
+            "additionalProperties" => Ok(TableKeysOrderGroupKind::AdditionalKeys),
+            "patternProperties" => Ok(TableKeysOrderGroupKind::PatternKeys),
+            _ => Err("Invalid table group"),
+        }
+    }
+}
+
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 #[cfg_attr(feature = "serde", serde(rename_all = "kebab-case"))]
